@@ -1,6 +1,10 @@
 import ctypes
+import sys
 
-lib = ctypes.cdll.LoadLibrary( '/'.join(__file__.split("/")[:-1]) + "/libminesweeper.so")
+if sys.platform.startswith("win"):
+    lib = ctypes.cdll.LoadLibrary( '\\'.join(__file__.split("\\")[:-1]) + "\\libminesweeper.dll")
+else:
+    lib = ctypes.cdll.LoadLibrary( '/'.join(__file__.split("/")[:-1]) + "/libminesweeper.so")
 
 lib.DELETE.argtypes = [ctypes.c_void_p]
 
